@@ -27,11 +27,14 @@ dealing with this directly.
 
 use strict;
 use base 'Class::Accessor';
+use Carp;
 
-__PACKAGE__->mk_accessors(qw/name accessor mutator/);
+__PACKAGE__->mk_accessors(
+	qw/name accessor mutator placeholder is_constrained/
+);
 
 use overload
-	'""' => sub { shift->name_lc },
+	'""'     => sub { shift->name_lc },
 	fallback => 1;
 
 =head2 new
@@ -43,8 +46,17 @@ A new object for this column.
 =cut
 
 sub new {
-	my ($class, $name) = @_;
-	bless { name => $name, _groups => {} }, $class;
+	my $class = shift;
+	my $name  = shift or croak "Column needs a name";
+	my $opt   = shift || {};
+	return $class->SUPER::new(
+		{
+			name        => $name,
+			_groups     => {},
+			placeholder => '?',
+			%$opt,
+		}
+	);
 }
 
 sub name_lc { lc shift->name }
