@@ -4,15 +4,18 @@ BEGIN { unshift @INC, './t/testlib'; }
 use base 'MyBase';
 
 use strict;
+use Class::DBI::Column;
 
 __PACKAGE__->set_table();
-__PACKAGE__->columns(All => qw/myid name val tdate/);
+__PACKAGE__->columns(
+	All => qw/myid name val/,
+	Class::DBI::Column->new(tdate => { placeholder => 'IF(1, CURDATE(), ?)' })
+);
 __PACKAGE__->has_a(
 	tdate   => 'Date::Simple',
 	inflate => sub { Date::Simple->new(shift) },
 	deflate => 'format',
 );
-__PACKAGE__->find_column('tdate')->placeholder("IF(1, CURDATE(), ?)");
 
 sub create_sql {
 	return qq{
